pub struct GetAllContactResponse {
pub contact_methods: Vec<Contact>,
}Expand description
Response for getting all contacts of a specific type.
Fields
contact_methods: Vec<Contact>The list of contact methods of the requested type.